==> plasma-phone-components-5.17.90.tar.xz: plasma-phone-components-5.17.90/bin/plasma-mobile.desktop.cmake <==
[Desktop Entry]
Exec=dbus-run-session ${CMAKE_INSTALL_FULL_BINDIR}/kwinwrapper
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/kwinwrapper
DesktopNames=KDE
Name=Plasma Mobile
Name[ca]=Plasma Mòbil
Name[ca@valencia]=Plasma Mòbil
Name[cs]=Plasma Mobile
Name[de]=Plasma Mobile
Name[en_GB]=Plasma Mobile
Name[es]=Plasma Mobile
Name[et]=Plasma Mobile
Name[eu]=Plasma Mugikorra
Name[fi]=Plasma Mobile
Name[fr]=Plasma Mobile
Name[gl]=Plasma Mobile
Name[hu]=Plasma Mobile
Name[ia]=Plasma Mobile
Name[id]=Plasma Mobile
Name[it]=Plasma Mobile
Name[ko]=Plasma 모바일
Name[lt]=Plasma mobilioji sąsaja
Name[nl]=Plasma-mobiel
Name[nn]=Plasma Mobile
Name[pl]=Plazma Mobile
Name[pt]=Plasma Mobile
Name[pt_BR]=Plasma Mobile
Name[sk]=Plasma Mobile
Name[sv]=Plasma mobil
Name[uk]=Мобільна Плазма
Name[x-test]=xxPlasma Mobilexx
Name[zh_TW]=Plasma 行動
Comment=Plasma Mobile by KDE
Comment[ca]=Plasma Mòbil, creat per la comunitat KDE
Comment[ca@valencia]=Plasma Mòbil, creat per la comunitat KDE
Comment[cs]=Plasma Mobile od KDE
Comment[de]=Plasma Mobile von KDE
Comment[en_GB]=Plasma Mobile by KDE
Comment[es]=Plasma Mobile creado por KDE
Comment[et]=KDE Plasma Mobile
Comment[eu]=Plasma Mugikorra KDEk egina
Comment[fi]=KDE:n Plasma Mobile
Comment[fr]=Plasma Mobile par KDE
Comment[gl]=Plasma Mobile de KDE
Comment[hu]=Plasma Mobile a KDE-től
Comment[ia]=Plasma Mobile per KDE
Comment[id]=Plasma Mobile oleh KDE
Comment[it]=Plasma Mobile creato da KDE
Comment[ko]=KDE의 Plasma 모바일
Comment[lt]=Plasma mobilioji sąsaja pagal KDE
Comment[nl]=Plasma-mobiel door KDE
Comment[nn]=Plasma Mobile frå KDE
Comment[pl]=Plazma Mobile stworzona przez KDE
Comment[pt]=Plasma Mobile do KDE
Comment[pt_BR]=Plasma Mobile do KDE
Comment[sk]=Plasma Mobile od KDE
Comment[sv]=Plasma mobil av KDE
Comment[uk]=Мобільна Плазма від KDE
Comment[x-test]=xxPlasma Mobile by KDExx
Comment[zh_TW]=來自 KDE 的 Plasma 行動作業系統
X-KDE-PluginInfo-Version=${PROJECT_VERSION}

==> plasma-phone-components-5.19.2.tar.xz: plasma-phone-components-5.19.2/bin/plasma-mobile.desktop.cmake <==
[Desktop Entry]
Exec=dbus-run-session ${CMAKE_INSTALL_FULL_BINDIR}/kwinwrapper
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/kwinwrapper
DesktopNames=KDE
Name=Plasma Mobile
Name[ca]=Plasma Mòbil
Name[ca@valencia]=Plasma Mòbil
Name[cs]=Plasma Mobile
Name[da]=Plasma Mobile
Name[de]=Plasma Mobile
Name[en_GB]=Plasma Mobile
Name[es]=Plasma Mobile
Name[et]=Plasma Mobile
Name[eu]=Plasma Mugikorra
Name[fi]=Plasma Mobile
Name[fr]=Plasma Mobile
Name[gl]=Plasma Mobile
Name[hu]=Plasma Mobile
Name[ia]=Plasma Mobile
Name[id]=Plasma Mobile
Name[it]=Plasma Mobile
Name[ko]=Plasma 모바일
Name[lt]=Plasma mobilioji sąsaja
Name[nl]=Plasma-mobiel
Name[nn]=Plasma Mobile
Name[pl]=Plazma Mobile
Name[pt]=Plasma Mobile
Name[pt_BR]=Plasma Mobile
Name[ru]=Plasma Mobile
Name[sk]=Plasma Mobile
Name[sv]=Plasma mobil
Name[uk]=Мобільна Плазма
Name[x-test]=xxPlasma Mobilexx
Name[zh_CN]=Plasma Mobile
Name[zh_TW]=Plasma 行動
Comment=Plasma Mobile by KDE
Comment[ca]=Plasma Mòbil, creat per la comunitat KDE
Comment[ca@valencia]=Plasma Mòbil, creat per la comunitat KDE
Comment[cs]=Plasma Mobile od KDE
Comment[da]=Plasma Mobile fra KDE
Comment[de]=Plasma Mobile von KDE
Comment[en_GB]=Plasma Mobile by KDE
Comment[es]=Plasma Mobile creado por KDE
Comment[et]=KDE Plasma Mobile
Comment[eu]=Plasma Mugikorra KDEk egina
Comment[fi]=KDE:n Plasma Mobile
Comment[fr]=Plasma Mobile par KDE
Comment[gl]=Plasma Mobile de KDE
Comment[hu]=Plasma Mobile a KDE-től
Comment[ia]=Plasma Mobile per KDE
Comment[id]=Plasma Mobile oleh KDE
Comment[it]=Plasma Mobile creato da KDE
Comment[ko]=KDE의 Plasma 모바일
Comment[lt]=Plasma mobilioji sąsaja pagal KDE
Comment[nl]=Plasma-mobiel door KDE
Comment[nn]=Plasma Mobile frå KDE
Comment[pl]=Plazma Mobile stworzona przez KDE
Comment[pt]=Plasma Mobile do KDE
Comment[pt_BR]=Plasma Mobile do KDE
Comment[ru]=KDE Plasma Mobile
Comment[sk]=Plasma Mobile od KDE
Comment[sv]=Plasma mobil av KDE
Comment[uk]=Мобільна Плазма від KDE
Comment[x-test]=xxPlasma Mobile by KDExx
Comment[zh_CN]=KDE Plasma Mobile
Comment[zh_TW]=來自 KDE 的 Plasma 行動作業系統
X-KDE-PluginInfo-Version=${PROJECT_VERSION}
